@@ -440,7 +440,14 @@ class TC_00_InputProxy(ExtraTestCase):
         time.sleep(2)
         self.allow_service('qubes.InputMouse')
         # trigger GUI startup
-        self.vm.run("true", gui=True, wait=True)
+        try:
+            # R4.0+
+            p = self.loop.run_until_complete(
+                asyncio.create_subprocess_exec('qvm-start-gui', self.vm.name))
+            self.loop.run_until_complete(p.communicate())
+        except (FileNotFoundError, AttributeError):
+            # R3.2
+            self.vm.run("true", gui=True, wait=True)
         self.find_device_and_start_listener()
         self.emit_event('REL_X', 1)
         self.emit_event('REL_X', 1)
